@@ -3132,7 +3132,7 @@ e_cache_class_init (ECacheClass *klass)
 		G_TYPE_STRING,
 		G_TYPE_STRING,
 		G_TYPE_STRING,
-		G_TYPE_HASH_TABLE,
+		E_TYPE_CACHE_COLUMN_VALUES,
 		G_TYPE_BOOLEAN,
 		G_TYPE_CANCELLABLE,
 		G_TYPE_POINTER);
