@@ -25,6 +25,7 @@
 
 const gchar *	_libedataserver_get_imagesdir		(void) G_GNUC_CONST;
 const gchar *	_libedataserver_get_credentialmoduledir	(void) G_GNUC_CONST;
+const gchar *	_libedataserver_get_uimoduledir		(void) G_GNUC_CONST;
 
 #undef E_DATA_SERVER_IMAGESDIR
 #define E_DATA_SERVER_IMAGESDIR _libedataserver_get_imagesdir ()
@@ -32,6 +33,9 @@ const gchar *	_libedataserver_get_credentialmoduledir	(void) G_GNUC_CONST;
 #undef E_DATA_SERVER_CREDENTIALMODULEDIR
 #define E_DATA_SERVER_CREDENTIALMODULEDIR _libedataserver_get_credentialmoduledir ()
 
+#undef E_DATA_SERVER_UIMODULEDIR
+#define E_DATA_SERVER_UIMODULEDIR _libedataserver_get_uimoduledir ()
+
 #endif	/* G_OS_WIN32 */
 
 #endif	/* LIBEDATASERVER_PRIVATE_H */
